BandwidthMonitoringEventCounters

Struct BandwidthMonitoringEventCounters 

pub struct BandwidthMonitoringEventCounters { /* private fields */ }
Bandwidth Monitoring Event Counters Information (LEAF=0x8000_0020_x3).

Platforms

✅ AMD ❌ Intel

Implementations

Source

impl BandwidthMonitoringEventCounters

pub fn number_events(&self) -> u32

Get Number of configurable bandwidth events

pub fn has_l3_cache_lcl_bw_fill_mon(&self) -> bool

Reads to local DRAM memory is supported if set.

pub fn has_l3_cache_rmt_bw_fill_mon(&self) -> bool

Reads to remote DRAM memory is supported if set.

pub fn has_l3_cache_lcl_bw_nt_wr_mon(&self) -> bool

Non-temporal writes to local memory is supported if set.

pub fn has_l3_cache_rmt_bw_nt_wr_mon(&self) -> bool

Non-temporal writes to remote memory is supported if set.

pub fn has_l3_cache_lcl_slow_bw_fill_mon(&self) -> bool

Reads to local memory identified as “Slow Memory” is supported if set.

pub fn has_l3_cache_rmt_slow_bw_fill_mon(&self) -> bool

Reads to remote memory identified as “Slow Memory” is supported if set.

pub fn has_l3_cache_vic_mon(&self) -> bool

Dirty victim writes to all types of memory is supported if set.