ExtendedFeatureIdentification2

Struct ExtendedFeatureIdentification2 

pub struct ExtendedFeatureIdentification2 { /* private fields */ }
Extended Feature Identification 2 (LEAF=0x8000_0021).

Platforms

✅ AMD ❌ Intel

Implementations

Source

impl ExtendedFeatureIdentification2

pub fn has_no_nested_data_bp(&self) -> bool

Processor ignores nested data breakpoints if set

pub fn has_lfence_always_serializing(&self) -> bool

LFENCE is always dispatch serializing if set

pub fn has_smm_pg_cfg_lock(&self) -> bool

SMM paging configuration lock supported if set

pub fn has_null_select_clears_base(&self) -> bool

Null segment selector loads also clear the destination segment register base and limit supported if set

pub fn has_upper_address_ignore(&self) -> bool

Upper Address Ignore is supported if set

pub fn has_automatic_ibrs(&self) -> bool

Automatic IBRS if set

pub fn has_no_smm_ctl_msr(&self) -> bool

SMM_CTL MSR (C001_0116h) is not supported if set

pub fn has_prefetch_ctl_msr(&self) -> bool

Prefetch control MSR supported if set

pub fn has_cpuid_user_dis(&self) -> bool

CPUID disable for non-privileged software if set

pub fn microcode_patch_size(&self) -> u16

The size of the Microcode patch in 16-byte multiples. If 0, the size of the patch is at most 5568 (15C0h) bytes.